@@ -54,7 +54,7 @@ class DfConverter:
             # Prefix to columns
             ndf = ndf.add_prefix(c + '.')
             # Concat dataframe
-            dataframe = pd.concat([dataframe, ndf], axis=1)
+            dataframe = pd.concat([dataframe, ndf], axis=1, ignore_index=True)
             # Drop column
             if drop:
                 dataframe.drop(c, axis=1, inplace=True)
